X-Git-Url: https://git.p6c8.net/jirafeau_mojo42.git/blobdiff_plain/30a3728e3002f864820531af817364a7b40c9cf3..cd4892472b534b68a094ea582f79efc27dda3924:/index.php?ds=sidebyside
diff --git a/index.php b/index.php
index e4cfa20..faeb8db 100644
--- a/index.php
+++ b/index.php
@@ -35,8 +35,14 @@ if (has_error()) {
require(JIRAFEAU_ROOT . 'lib/template/header.php');
/* Check if user is allowed to upload. */
-// First check: Challenge by IP
-if (true === jirafeau_challenge_upload_ip($cfg['upload_ip'], get_ip_address($cfg))) {
+// First check: Challenge by IP NO PASSWORD
+if (true === jirafeau_challenge_upload_ip_without_password($cfg, get_ip_address($cfg))) {
+ $_SESSION['upload_auth'] = true;
+ $_POST['upload_password'] = '';
+ $_SESSION['user_upload_password'] = $_POST['upload_password'];
+}
+// Second check: Challenge by IP
+elseif (true === jirafeau_challenge_upload_ip($cfg, get_ip_address($cfg))) {
// Is an upload password required?
if (jirafeau_has_upload_password($cfg)) {
// Logout action
@@ -101,7 +107,7 @@ else {
-
+
-
+
-
+
-
+
- ')"/> + 0) { + echo t('2_BIG') . ', ' . t('FILE_LIM') . " " . $cfg['maximal_upload_size'] . " MB."; + } + ?>')"/>
: | -- | ' . t('ONE_TIME_DL') . ': | '; + echo ''; + } + ?> |
- | + | |
@@ -224,13 +238,18 @@ else { |